import { AxiosResponse } from 'axios';
import { authApi } from './api';

const localUrl = `${window.location.protocol}//${window.location.hostname}` + (window.location.port ? `:${window.location.port}/` : '/')

/** Data request type for auth request */
export type AuthRequestData = {
    username: string;
    password: string;
};

/** Data request type for auth request with code flow */
export type AuthCodeRequestData = {
    code: string;
    code_verifier: string;
};

/** Data response type for auth request */
type AuthResponseData = {
    access_token: string;
    expires_in: number;
    token_type: string;
    scope: string;
};

/** Data response type for create transaction request with axios wrapper */
export type AuthResponse = AxiosResponse<AuthResponseData>;

export default {
    authenticate: async (data: AuthRequestData): Promise<AuthResponse> => {
        const params = new URLSearchParams();
        params.append('grant_type', process.env.REACT_GRANT_TYPE ?? '');
        params.append('scope', process.env.REACT_SCOPE ?? '');
        params.append('client_id', process.env.REACT_APP_CLIENT_ID ?? '');
        params.append('client_secret', process.env.REACT_APP_CLIENT_SECRET ?? '');
        params.append('username', data.username);
        params.append('password', data.password);

        return await authApi.post('/auth/connect/token', params);
    },
    authenticateCode: async (data: AuthCodeRequestData): Promise<AuthResponse> => {
        const params = new URLSearchParams();
        params.append('grant_type', process.env.REACT_GRANT_TYPE ?? '');
        params.append('scope', process.env.REACT_SCOPE ?? '');
        params.append('client_id', process.env.REACT_APP_CLIENT_ID ?? '');
        params.append('client_secret', process.env.REACT_APP_CLIENT_SECRET ?? '');
        params.append('redirect_uri', `${localUrl}try-any-skill/` ?? '');
        params.append('code_verifier', data.code_verifier);
        params.append('code', data.code);

        return await authApi.post('/auth2/connect/token', params);
    }
};
