import { AxiosResponse } from 'axios';
import { publicApi } from './api';
import {ResultFile, TransactionStatus, TransactionDocument } from './types';

/** Data request type for create transaction launch request */
export type CreateTransactionLaunchRequestData = {
    skillId: string;
    files: FormData;
};

/** Data request type for create transaction request */
export type CreateTransactionRequestData = {
    skillId: string;
};

/** Data response type for create transaction request */
type CreateTransactionResponseData = {
    transactionId: string;
};

/** Data response type for create transaction request with axios wrapper */
export type CreateTransactionResponse = AxiosResponse<CreateTransactionResponseData>;

/** Data response type for get transaction status request */
type GetTransactionInfoResponseData = {
    status: TransactionStatus;
    manualReviewLink?: string;
    sourceFiles?: Array<{
        id: string;
        name: string;
    }>;
    documents?: [
        {
            id?: string;
            resultFiles?: ResultFile[];
            classification?: {
                resultClass?: {
                    id: string;
                    name: string;
                };
            };
        },
    ];
};

/** Data response type for get transaction status request with axios wrapper */
export type GetTransactionInfoResponse = AxiosResponse<GetTransactionInfoResponseData>;

/** Data response type for delete transaction request */
// Well, it is empty
type DeleteTransactionResponseData = Record<string, never>;
/** Data response type for delete transaction request with axios wrapper */
export type DeleteTransactionResponse = AxiosResponse<DeleteTransactionResponseData>;

/** Data response type for download file request with axios wrapper */
export type DownloadFileResponse = AxiosResponse<string>;

/** Data request type for get mobile input link request */
export type GetMobileInputLinkData = {
    transactionId: string;
    mobileInputLink: string;
};

/** Data response type for get mobile input link request */
export type GetMobileInputLinkResponse = AxiosResponse<GetMobileInputLinkData>;

/** Data response type for get transaction documents */
type GetDocumentsForTransactionData = TransactionDocument[]

/** Data response type for get transaction documents request with axios wrapper */
export type GetDocumentsForTransactionResponse = AxiosResponse<GetDocumentsForTransactionData>;

export default {
    createTransactionLaunch: async (data: CreateTransactionLaunchRequestData): Promise<CreateTransactionResponse> =>
        publicApi.post('/v1/transactions/launch', data.files, {
            params: {
                skillId: data.skillId,
            },
        }),

    createTransaction: async (data: CreateTransactionRequestData): Promise<CreateTransactionResponse> =>
        publicApi.post('/v1/transactions', data),

    getTransactionInfo: async (transactionId: string): Promise<GetTransactionInfoResponse> =>
        publicApi.get(`/v1/transactions/${transactionId}`, {}),

    deleteTransaction: async (transactionId: string): Promise<DeleteTransactionResponse> =>
        publicApi.delete(`/v1/transactions/${transactionId}`, {}),

    addDocumentTransaction: async (transactionId: string): Promise<DeleteTransactionResponse> =>
        publicApi.delete(`/v1/transactions/${transactionId}`, {}),

    downloadFile: async (transactionId: string, transactionFileId: string): Promise<DownloadFileResponse> =>
        publicApi.get(`/v1/transactions/${transactionId}/files/${transactionFileId}/download`, {}),

    downloadFileAsBuffer: async (transactionId: string, transactionFileId: string): Promise<DownloadFileResponse> =>
        publicApi.get(`/v1/transactions/${transactionId}/files/${transactionFileId}/download`, {
            responseType: 'arraybuffer',
        }),
    getMobileLink: async (transactionId: string ): Promise<GetMobileInputLinkResponse> =>
        publicApi.post(`/v1/transactions/${transactionId}/mobileInputLink`, {}),

    getDocumentsForTransaction: async (transactionId: string): Promise<GetDocumentsForTransactionResponse> =>
        publicApi.get(`/v1/transactions/${transactionId}/documents`, {}),

    downloadDocumentSourceFile: async (transactionId: string, documentId: string, fileId: string): Promise<any> =>
        publicApi.get(`/v1/transactions/${transactionId}/documents/${documentId}/sourceFiles/${fileId}/download`, {
            responseType: 'arraybuffer',
        })
};
