/** Transaction status enumeration */
export enum TransactionStatus {
    LOCAL = 'local',
    NEW = 'New',
    UPLOAD = 'Upload',
    PROCESSING = 'Processing',
    PROCESSED = 'Processed',
    REVIEW = 'Review',
    FAILED = 'Failed',
    NONE = 'NONE',
}

/** File status enumeration */
export enum FileStatus {
    ADDED = 'Added',
    UPLOAD = 'Upload',
    DELETE = 'Delete',
    FAILED = 'Failed',
    UPLOADED = 'Uploaded',
}

/** File status enumeration */
export type TransactionFileType = {
    /** Uploaded file id */
    fileId: string;
    /** Uploaded file */
    file: File;
    /** File status*/
    status: FileStatus;
}


/** File type enumeration */
export enum FileType {
    JSON = 'json',
    PDF = 'pdf',
}

/** Skill object type */
export type Skill = {
    /** Skill id */
    id: string;
    /** Skill name */
    name: string;
    /** Skill type */
    type: string;
};

/** Transaction object type */
export type Transaction = {
    /** Transaction local uuid */
    uuid: string;
    /** Transaction mobile mode */
    isMobile?: boolean;
    /** Transaction id */
    transactionId?: string;
    /** Skill id specific for transactions */
    skillId?: string | null;
    /** Transaction status */
    status: TransactionStatus;

    /* params for transaction */
    /** Uploaded files */
    transactionFiles: TransactionFileType[];
    /** File ids uploaded by mobile capture */
    mobileSourceFileIds?: string[];
    /** Uploaded file url */
    transactionFileUrl?: string;

    /* params for web verification */
    /** Review link */
    reviewLink?: string;

    /* params for classification */
    /** Result document class names */
    resultClassNames?: string[];

    /* params for file result */
    resultFiles?: ResultFile[]

    /** Deleting flag */
    deleting?: boolean;

    /** Downloading source files flag */
    downloadingSource?: boolean

    mobileUrl?: string
};

/** Transaction object type */
export type ResultFile = {
    fileIndex?: number
    fileId: string,
    fileName: string,
    type: string
}

/** Transaction Source file type */
export type SourceFile = {
    id: string,
    name: string
}

/** Transaction Document type */
export type TransactionDocument = {
    documentId: string,
    sourceFiles?: SourceFile[]
}