import React, {useRef} from 'react';
import cn from 'classnames';

import styles from './ClassDropdownComponent.module.scss';
import {useOnClickOutside} from "@src/hooks/useClickOutside";

type ClassDropdownComponentProps = {
    /** Show drop down flag */
    isShow: boolean;
    /** Array of transaction classes */
    classes: Array<string>;
    /** Event handler for hide drop down */
    hideDropdown: (event: MouseEvent | TouchEvent) => void;
    /** Event handler for show toggle */
    toggleShow: () => void;
};

/**
 *  Component to render a dropdown for display classes
 */
const ClassDropdownComponent = ({
                                   isShow, classes,
                                   hideDropdown,
                                   toggleShow
                               }: ClassDropdownComponentProps) => {
    const getClassListItem = (transactionClass: string, index: number) => {
        return (
            <div className={styles.class} key={index}>
                {transactionClass}
            </div>
        )
    };

    const ref = useRef(null);

    useOnClickOutside(ref, hideDropdown)

    return (
        <div className={styles.dropdown} ref={ref}>
            <button
                className={cn([styles.dropButton, {[styles.dropButtonActive]: isShow}])}
                onClick={toggleShow}
                type="button"
            >
                <span className={styles.dropTitle}>
                    <span>Classes: {classes.length}</span>
                </span>
            </button>
            {isShow && <div className={styles.dropdownContent}>{
                classes.map((transactionClass, index) => {
                    return getClassListItem(transactionClass, index)
                })
            }</div>}
        </div>
    );
};

export default ClassDropdownComponent;
