import React from 'react';
import ReactDOM from 'react-dom';
import { resource } from '@assets/text/resources';
import cn from 'classnames';
import styles from './DeleteModalComponent.module.scss';
import DeleteIcon from "@assets/icons/ic_delete.svg";

interface DeleteModalComponentProps {
    deleteHandler: () => void;
    closeHandler: () => void;
    titleText: string;
    subtitleText: string;
}

/**
 *  Component to render a qr code modal window
 */
function DeleteModalComponent({ deleteHandler, closeHandler, titleText, subtitleText }: DeleteModalComponentProps) {
    const parent = document.body as HTMLElement;


    return ReactDOM.createPortal(
        <div className={styles.backdrop} onClick={closeHandler}>
            <div className={styles.modal}>
                <div>
                    <DeleteIcon/>
                </div>
                <div className={styles.modalContent}>
                    <div className={styles.title}>{titleText}</div>
                    <div className={styles.subtitle}>{subtitleText}</div>
                    <div className={styles.buttonContainer}>
                        <button onClickCapture={closeHandler} type="button" className={cn([styles.button, styles.accentButton])} >
                            {resource.button.cancel}
                        </button>
                        <button type="button" className={cn([styles.button, styles.secondButton])} onClick={deleteHandler}>
                            {resource.button.delete}
                        </button>
                    </div>
                </div>
            </div>
        </div>,
        parent,
    );
}

export default DeleteModalComponent;
