import React, {useRef} from 'react';
import cn from 'classnames';

import styles from './DownloadDropdownComponent.module.scss';
import DownloadIcon from '@assets/icons/ic_download.svg';
import {ResultFile } from '@api/types';
import {useOnClickOutside} from "@src/hooks/useClickOutside";
import {getFileExpansion, getFileType, getSelfName} from "@utils/getFileAttribute";

type DownloadDropdownComponentProps = {
    /** Show drop down flag */
    isShow: boolean;
    /** Available array of files */
    files: Array<ResultFile>;
    /** Event handler for download result of transaction */
    handleDownload: (file: ResultFile) => void;
    /** Event handler for hide drop down */
    hideDropdown: (event: MouseEvent | TouchEvent) => void;
    /** Event handler for show toggle */
    toggleShow: () => void;
    /** Is top */
    isTop: boolean
};

/**
 *  Component to render a dropdown for display and select skills
 */
const DownloadDropdownComponent = ({
    isShow,
    files,
    handleDownload,
    hideDropdown,
    toggleShow,
    isTop
}: DownloadDropdownComponentProps) => {
    const getDownloadListItem = (file: ResultFile) => {
        const handleClick = ()=> {
            handleDownload(file)
        }
        return (<button
            key={file.fileId}
            data-value={file.fileId}
            onClick={handleClick}
            type="button"
            title={file.fileName}
        >
            <span className={styles.fileName}>
                {getSelfName(file.fileName)}
            </span>
            <span>{getFileType(file.fileName) && "_" + getFileType(file.fileName)}{getFileExpansion(file.fileName)}</span>
        </button>)
    };

    const getDivider = () => {
        return (<div className={styles.divider}/>)
    };

    const downloadFiles = files.sort(((a, b) => {
        if (a.fileIndex && b.fileIndex) {
            return a.fileIndex - b.fileIndex
        } else {
            return 0
        }
    }))

    let fileIndex = 0;
    const downloadList:JSX.Element[] = [];
    downloadFiles.forEach((file) => {
        if(fileIndex == file.fileIndex) {
            downloadList.push(getDownloadListItem(file));
        } else {
            downloadList.push(getDivider())
            downloadList.push(getDownloadListItem(file));
            fileIndex++
        }
    })

    const ref = useRef(null);

    useOnClickOutside(ref, hideDropdown)

    return (
        <div className={styles.dropdown} ref={ref}>
            <button
                className={cn([styles.dropButton, {[styles.dropButtonActive]: isShow}])}
                onClick={toggleShow}
                type="button"
            >
                <span className={styles.dropTitle}>
                    <DownloadIcon className={styles.icon}/>
                    <span>RESULTS</span>
                </span>
            </button>
            {isShow && <div className={styles.dropdownContent} style={{bottom: isTop?"100%": "inherit"}}>{downloadList}</div>}
        </div>
    );
};

export default DownloadDropdownComponent;
