import React, {useRef} from 'react';
import cn from 'classnames';

import styles from './FileDropdownComponent.module.scss';
import {TransactionFileType} from '@api/types';
import {useOnClickOutside} from "@src/hooks/useClickOutside";
import {getFileExpansion, getFileType, getSelfName} from "@utils/getFileAttribute";
import DeleteIcon from "@assets/icons/ic_delete.svg";

type FileDropdownComponentProps = {
    /** Show drop down flag */
    isShow: boolean;
    /** Array of transaction files */
    files: Array<TransactionFileType>;
    /** Event handler for delete transaction file*/
    handleDelete: (file: TransactionFileType) => void;
    /** Event handler for hide drop down */
    hideDropdown: (event: MouseEvent | TouchEvent) => void;
    /** Event handler for show toggle */
    toggleShow: () => void;
};

/**
 *  Component to render a dropdown for display transaction files
 */
const FileDropdownComponent = ({
                                   isShow, files,
                                   handleDelete,
                                   hideDropdown,
                                   toggleShow
                               }: FileDropdownComponentProps) => {
    const getDownloadListItem = (transactionFile: TransactionFileType) => {
        const handleClick = () => {
            handleDelete(transactionFile)
        }
        const fileName = transactionFile.file.name
        return (
            <div className={styles.file} key={transactionFile.fileId}  title={fileName}>
                <span>
                    <span className={styles.fileName}>
                        {getSelfName(fileName)}
                    </span>
                    <span>{getFileType(fileName) && "_" + getFileType(fileName)}{getFileExpansion(fileName)}</span>
                </span>
                <span onClick={handleClick} className={styles.deleteFile}>
                    <DeleteIcon />
                </span>
            </div>
        )
    };

    const ref = useRef(null);

    useOnClickOutside(ref, hideDropdown)

    return (
        <div className={styles.dropdown} ref={ref}>
            <button
                className={cn([styles.dropButton, {[styles.dropButtonActive]: isShow}])}
                onClick={toggleShow}
                type="button"
            >
                <span className={styles.dropTitle}>
                    <span>Files: {files.length}</span>
                </span>
            </button>
            {isShow && <div className={styles.dropdownContent}>{
                files.map(transactionFile => {
                    return getDownloadListItem(transactionFile)
                })
            }</div>}
        </div>
    );
};

export default FileDropdownComponent;
