import React, { useCallback, useState } from 'react';
import cn from 'classnames';

import styles from './InputComponent.module.scss';

import IconVisible from '@assets/icons/ic_visible.svg';
import IconInvisible from '@assets/icons/ic_invisible.svg';

interface InputComponentProps {
    /** Text displayed in the input */
    value: string;
    /** Text displayed on the input */
    label: string;
    /** Show error flag */
    error: boolean;
    /** onChange listener */
    onChange: (event: React.ChangeEvent<HTMLInputElement>) => void;
}

/**
 *  Component to render a styled input
 */
function InputPasswordComponent({ value, label, error, onChange }: InputComponentProps) {
    const [visible, setVisibility] = useState(false);
    const [labelAsPlaceholder, setLabelAsPlaceholder] = useState(!value);

    const onInputFocus = useCallback(() => {
        setLabelAsPlaceholder(false);
    }, []);

    const onInputBlur = useCallback(() => {
        if (!value) setLabelAsPlaceholder(!value);
    }, [value]);

    const handleAutoFill = useCallback((event: React.AnimationEvent) => {
        if (event.animationName === 'onAutoFillStart') {
            setLabelAsPlaceholder(false);
        }
    }, []);

    return (
        <label className={styles.input}>
            <input
                value={value}
                onAnimationStart={handleAutoFill}
                onChange={onChange}
                onFocus={onInputFocus}
                onBlur={onInputBlur}
                className={cn(
                    [styles.inputField],
                    { [styles.inputFieldFocus]: !labelAsPlaceholder },
                    { [styles.error]: error },
                )}
                type={visible ? 'text' : 'password'}
                placeholder=" "
            />
            <span className={styles.inputText}>{label}</span>
            {visible ? (
                <IconVisible
                    onClick={(event) => {
                        event.preventDefault();
                        setVisibility(!visible);
                    }}
                    className={styles.inputEye}
                />
            ) : (
                <IconInvisible
                    onClick={(event) => {
                        event.preventDefault();
                        setVisibility(!visible);
                    }}
                    className={styles.inputEye}
                />
            )}
        </label>
    );
}

export default InputPasswordComponent;
