import React from 'react';
import styles from './PageHeaderComponent.module.scss';
import Logo from "@assets/logo_small.svg";
import MobileUploadButtonContainer from "@commonContainers/MobileUploadButtonContainer/MobileUploadButtonContainer";
import BrowseButtonContainer from "@commonContainers/BrowseButtonContainer/BrowseButtonContainer";
import {resource} from "@assets/text/resources";
import EditMenuContainer from "@commonContainers/EditMenuContainer/EditMenuContainer";

type PageHeaderComponentProps = {
    /** Card view visibility flag */
    isCardView: boolean;
    /** Handler for flip view click */
    handleFlipView: () => void;
    /** Handler for log out click */
    handleLogOut: () => void;
};

/**
 *  Component to render page header
 */
function PageHeaderComponent({ isCardView, handleFlipView, handleLogOut }: PageHeaderComponentProps) {
    return (
        <>
            <div className={styles.header}>
                <span className={styles.title}>
                    <Logo className={styles.logo} />
                </span>
                <div className={styles.mobileUploadContainer}>
                    <MobileUploadButtonContainer />
                </div>
                <BrowseButtonContainer text={resource.button.uploadDoc} />
                <EditMenuContainer isCardView={isCardView} handleFlipView={handleFlipView} handleLogOut={handleLogOut}/>
            </div>
        </>
    );
}

export default PageHeaderComponent;
