import React from 'react';
import ReactDOM from 'react-dom';
import {QRCodeSVG} from 'qrcode.react';
import { resource } from '@assets/text/resources';
import styles from './QRCodeModalComponent.module.scss';
import IconSpinner from '@assets/icons/ic_spinner_large.svg';

interface QRCodeModalComponentProps {
    mobileInputLink: string;
    closeHandler: () => void;
}

/**
 *  Component to render a qr code modal window
 */
function QRCodeModalComponent({ mobileInputLink, closeHandler }: QRCodeModalComponentProps) {
    const parent = document.body as HTMLElement;

    return ReactDOM.createPortal(
        <div className={styles.backdrop} onClick={closeHandler}>
            <div className={styles.modal}>
                <div className={styles.title}>{resource.title.mobileUpload}</div>
                {mobileInputLink ? <QRCodeSVG size={312} value={mobileInputLink} /> : <IconSpinner className={styles.rotateIcon} />}
                <div className={styles.subtitle}>{resource.title.scanQRCode}</div>
                <button type="button" className={styles.button}>
                    {resource.button.close}
                </button>
            </div>
        </div>,
        parent,
    );
}

export default QRCodeModalComponent;
