import React from 'react';
import IconDone from '@assets/icons/ic_done.svg';
import IconError from '@assets/icons/ic_warn.svg';
import IconWarn from '@assets/icons/ic_some_warn.svg';
import IconSpinner from '@assets/icons/ic_spinner.svg';
import styles from './StatusIconComponent.module.scss';
import { getNodeByTransactionStatus } from '@utils/getNode';
import { TransactionStatus } from '@api/types';

type StatusIconComponentProps = {
    /** Status of transaction */
    status: TransactionStatus;
};

/**
 *  Component to render a status icon
 */
function StatusIconComponent({ status }: StatusIconComponentProps) {
    return (
        <>
            {getNodeByTransactionStatus(status, {
                [TransactionStatus.LOCAL]: <IconWarn />,
                [TransactionStatus.NEW]: <IconSpinner className={styles.rotateIcon} />,
                [TransactionStatus.UPLOAD]: <IconSpinner className={styles.rotateIcon} />,
                [TransactionStatus.PROCESSING]: <IconSpinner className={styles.rotateIcon} />,
                [TransactionStatus.PROCESSED]: <IconDone />,
                [TransactionStatus.REVIEW]: <IconWarn />,
                [TransactionStatus.FAILED]: <IconError />,
                [TransactionStatus.NONE]: <IconWarn />,
            })}
        </>
    );
}

export default StatusIconComponent;
