import React from 'react';

import styles from './StatusTextComponent.module.scss';
import { getNodeByTransactionStatus } from '@utils/getNode';
import { resource } from '@assets/text/resources';
import { TransactionStatus } from '@api/types';

type StatusTextComponentProps = {
    /** Status of transaction */
    status: TransactionStatus;
    /** Transaction is mobile */
    isMobile?: boolean
};

/**
 *  Component to render a status text
 */
function StatusTextComponent({ status, isMobile = false }: StatusTextComponentProps) {
    return (
        <>
            {getNodeByTransactionStatus(status, {
                [TransactionStatus.LOCAL]: <span className={styles.default}>{resource.status.none}</span>,
                [TransactionStatus.NEW]: <span className={styles.default}>{isMobile? resource.status.mobileUpload:resource.status.uploading}</span>,
                [TransactionStatus.UPLOAD]: <span className={styles.default}>{resource.status.uploading}</span>,
                [TransactionStatus.PROCESSING]: <span className={styles.default}>{resource.status.processing}</span>,
                [TransactionStatus.PROCESSED]: <span className={styles.default}>{resource.status.processed}</span>,
                [TransactionStatus.REVIEW]: <span className={styles.default}>{resource.status.review}</span>,
                [TransactionStatus.FAILED]: <span className={styles.warning}>{resource.status.failed}</span>,
                [TransactionStatus.NONE]: <span className={styles.default}>{resource.status.none}</span>,
            })}
        </>
    );
}

export default StatusTextComponent;
