import React from 'react';
import styles from './TransactionBrowseButtonComponent.module.scss';
import AddFilesIcon from '@assets/icons/ic_add_files.svg';

interface TransactionBrowseButtonComponentProps {
    /** File input ref */
    hiddenFileInput: React.RefObject<HTMLInputElement>;
    /** Handler for input click */
    handleClick: () => void;
    /** Handler for file open */
    handleFile: (event: React.ChangeEvent<HTMLInputElement>) => void;
}

/**
 *  Component to render a styled button for browse documents
 */
function TransactionBrowseButtonComponent({
                                              hiddenFileInput,
                                              handleClick,
                                              handleFile,
                                          }: TransactionBrowseButtonComponentProps) {
    return (
        <>
            <input
                type="file"
                ref={hiddenFileInput}
                className={styles.input}
                accept=".pdf, .doc, .docx, .docm, .tiff, .tif, .jfif, .pjpeg, .jpeg, .pjp, .jpg, .png, .bmp, .dib, .gif, .odt, .rtf, .html, .htm, .txt, .rle, .jp2, .j2k, .jpf, .jpx, .jpc, .jb2, .jbig2"
                onChange={handleFile}
                multiple
            />
            <button
                type="button"
                className={styles.button}
                onClick={handleClick}
            >
                <AddFilesIcon/>
            </button>
        </>
    );
}

export default TransactionBrowseButtonComponent;
