import React, { useCallback, useState } from 'react';
import DownloadDropdownComponent from '@commonComponents/DownloadDropdownComponent/DownloadDropdownComponent';
import {ResultFile } from '@api/types';

type DownloadDropdownContainerProps = {
    /** Available array of skills */
    files: Array<ResultFile>;
    /** Event handler for download result of transaction */
    handleDownload: (file: ResultFile) => void;
    /** Is top */
    isTop?: boolean
};

/**
 *  Component to render a dropdown for display download files
 */
const DownloadDropDownContainer = ({
    files,
    handleDownload,
    isTop = false
}: DownloadDropdownContainerProps) => {
    const [show, setShow] = useState(false);
    const toggleShow = useCallback(() => {
        setShow(true);
    }, [setShow]);

    const hideDropdown = useCallback(
        () => {
            setShow(false);
        },
        [setShow],
    );

    const onDownload = (file: ResultFile)=>{
        handleDownload(file);
        setShow(false)
    }

    return (
        <DownloadDropdownComponent
            isShow={show}
            files={files}
            handleDownload={onDownload}
            hideDropdown={hideDropdown}
            toggleShow={toggleShow}
            isTop={isTop}
        />
    );
};

export default DownloadDropDownContainer;
