import React, { useCallback, useState } from 'react';
import EditMenuComponent from "@commonComponents/EditMenuComponent/EditMenuComponent";

type EditMenuContainerProps = {
    /** Card view visibility flag */
    isCardView: boolean;
    /** Event handler for flip view */
    handleFlipView: () => void;
    /** Handler for log out click */
    handleLogOut: () => void;
};

/**
 *  Component to render a dropdown for display edit menu
 */
const EditMenuContainer = ({
    isCardView,
    handleFlipView,
    handleLogOut
}: EditMenuContainerProps) => {
    const [show, setShow] = useState(false);
    const toggleShow = useCallback(() => {
        setShow(true);
    }, [setShow]);

    const hideDropdown = useCallback(
        () => {
            setShow(false);
        },
        [setShow],
    );

    const onFlipView = ()=>{
        setShow(false)
        handleFlipView();
    }

    return (
        <EditMenuComponent
            isShow={show}
            isCardView={isCardView}
            handleFlipView={onFlipView}
            handleLogOut={handleLogOut}
            hideDropdown={hideDropdown}
            toggleShow={toggleShow}
        />
    );
};

export default EditMenuContainer;
