import React, { useCallback, useState } from 'react';
import FileDropdownComponent from '@commonComponents/FileDropdownComponent/FileDropdownComponent';
import {TransactionFileType} from '@api/types';

type FileDropdownContainerProps = {
    /** Available array of transaction file */
    files: Array<TransactionFileType>;
    /** Event handler for delete file in transaction */
    handleDelete: (fileId: string) => void;
};

/**
 *  Component to render a dropdown for display transaction files
 */
const FileDropDownContainer = ({
    files,
    handleDelete
}: FileDropdownContainerProps) => {
    const [show, setShow] = useState(false);
    const toggleShow = useCallback(() => {
        setShow(true);
    }, [setShow]);

    const hideDropdown = useCallback(
        () => {
            setShow(false);
        },
        [setShow],
    );

    const onDelete = (file: TransactionFileType)=>{
        if(file.fileId) {
            handleDelete(file.fileId);
        }
    }

    return (
        <FileDropdownComponent
            isShow={show}
            files={files}
            handleDelete={onDelete}
            hideDropdown={hideDropdown}
            toggleShow={toggleShow}
        />
    );
};

export default FileDropDownContainer;
