import React, { useCallback, useRef } from 'react';
import { useDispatch } from 'react-redux';
import { v4 as uuid } from 'uuid';
import {FileStatus, TransactionFileType} from '@api/types';
import TransactionBrowseButtonComponent
    from "@commonComponents/TransactionBrowseButtonComponent/TransactionBrowseButtonComponent";
import {addFileToTransactionRequest} from "@ducks/Transaction/actions/addFileToTransactionActions";

interface TransactionButtonContainerProps {
    /** Transaction Id for add file */
    transactionId: string;
}

/**
 *  Component to render a styled button for browse documents
 */
const TransactionBrowseButtonContainer = ({transactionId}: TransactionButtonContainerProps) => {
    const hiddenFileInput = useRef<HTMLInputElement>(null);
    const dispatch = useDispatch();

    const handleClick = useCallback(() => {
        hiddenFileInput.current?.click();
    }, [hiddenFileInput]);

    const handleFile = useCallback(
        (event: React.ChangeEvent<HTMLInputElement>) => {
            const { files } = event.target;
            if (files && files.length > 0) {
                let transactionFiles: TransactionFileType[] = [];
                for (let index = 0 ; index<files.length; index++) {
                    transactionFiles = transactionFiles.concat({
                        file: files[index], fileId: uuid(), status: FileStatus.ADDED
                    })
                }
                dispatch(
                    addFileToTransactionRequest({
                        uuid: transactionId,
                        transactionFiles
                    }),
                );
                // eslint-disable-next-line no-param-reassign
                event.target.value = '';
            }
        },
        [dispatch],
    );

    return (
        <TransactionBrowseButtonComponent
            handleClick={handleClick}
            handleFile={handleFile}
            hiddenFileInput={hiddenFileInput}
        />
    );
};

export default TransactionBrowseButtonContainer;
