import { Type } from './actionTypes';
import { AuthActionTypes } from './actions/AuthActions';

export const initialState: AuthState = {
    /** Loader visibility flag */
    isLoading: false,
    /** auth error flag */
    hasError: false,
    /** auth success flag */
    isAuth: false,
};

/**
 * Auth reducer state type
 */
export interface AuthState {
    isLoading: boolean;
    hasError: boolean;
    isAuth: boolean;
}

/**
 * Auth reducer
 * @param state
 * @param action
 */
export const reducer = (state = initialState, action: AuthActionTypes): AuthState => {
    switch (action.type) {
        case Type.AUTH_REQUEST: {
            return {
                isAuth: false,
                isLoading: true,
                hasError: false,
            };
        }
        case Type.AUTH_SUCCESS: {
            return {
                isAuth: true,
                isLoading: false,
                hasError: false,
            };
        }
        case Type.AUTH_FAILED: {
            return {
                ...state,
                hasError: true,
                isLoading: false,
            };
        }
        case Type.AUTH_LOGOUT: {
            return {
                ...state,
                isAuth: false,
            };
        }
        default:
            return state;
    }
};
