import {
    createLocalTransactionError,
    createLocalTransactionRequest,
    createLocalTransactionSuccess,
} from './createLocalTransactionActions';
import MockFile from '../../../utils/mockFileUtil';
import { Type } from '../actionTypes';
import {FileStatus, TransactionStatus} from '../../../api/types';

const testFile = MockFile({
    type: 'image/png',
    size: 50000,
});

describe('Create local transaction action tests', () => {
    it('Create local transaction request', () => {
        const expectedAction = {
            type: Type.CREATE_LOCAL_TRANSACTION_REQUEST,
            payload: {
                transaction: {
                    uuid: 'uuid-1',
                    status: TransactionStatus.LOCAL,
                    transactionFile: testFile,
                },
            },
        };
        expect(
            createLocalTransactionRequest({
                transaction: {
                    uuid: 'uuid-1',
                    status: TransactionStatus.LOCAL,
                    transactionFiles: [{
                        fileId: 'uuid-file-1',
                        file: testFile,
                        status: FileStatus.ADDED
                    }]
                },
            }),
        ).toEqual(expectedAction);
    });

    it('Create local transaction success', () => {
        const expectedAction = {
            type: Type.CREATE_LOCAL_TRANSACTION_SUCCESS,
            payload: {
                transaction: {
                    uuid: 'uuid-1',
                    status: TransactionStatus.LOCAL,
                    transactionFiles: [{
                        fileId: 'uuid-file-1',
                        file: testFile,
                        status: FileStatus.ADDED
                    }]
                },
            },
        };
        expect(
            createLocalTransactionSuccess({
                transaction: {
                    uuid: 'uuid-1',
                    status: TransactionStatus.LOCAL,
                    transactionFiles: [{
                        fileId: 'uuid-file-1',
                        file: testFile,
                        status: FileStatus.ADDED
                    }]
                },
            }),
        ).toEqual(expectedAction);
    });

    it('Create local transaction failed', () => {
        const expectedAction = {
            type: Type.CREATE_LOCAL_TRANSACTION_ERROR,
            payload: {
                errorText: 'error',
            },
        };
        expect(
            createLocalTransactionError({
                errorText: 'error',
            }),
        ).toEqual(expectedAction);
    });
});
