import { GetActionsType } from '../../types';
import { Type } from '../actionTypes';
import {ResultFile, TransactionFileType, TransactionStatus} from '../../../api/types';

const GetTransactionActions = {
    getTransactionRequest: (payload: { uuid: string; transactionId: string; skillId: string; needLoadSource?: boolean}) => ({
        type: Type.GET_TRANSACTION_REQUEST,
        payload,
    }),

    getTransactionStart: (payload: { uuid: string; transactionId: string; skillId: string }) => ({
        type: Type.GET_TRANSACTION_START,
        payload,
    }),

    getTransactionRepeat: (payload: { uuid: string; transactionId: string }) => ({
        type: Type.GET_TRANSACTION_REPEAT,
        payload,
    }),

    getTransactionStop: (payload: { transactionId: string }) => ({
        type: Type.GET_TRANSACTION_STOP,
        payload,
    }),

    setTransactionDownloadSource: (payload: { uuid: string, isDownload: boolean }) => ({
        type: Type.SET_TRANSACTION_DOWNLOAD_SOURCE,
        payload,
    }),

    getTransactionSuccess: (payload: {
        uuid: string;
        status: TransactionStatus;
        sourceFiles?: TransactionFileType[];
        reviewLink?: string;
        resultFiles?: ResultFile[]
        resultClassNames?: string[];
    }) => ({
        type: Type.GET_TRANSACTION_SUCCESS,
        payload,
    }),

    getTransactionError: (payload: { errorText: string }) => ({
        type: Type.GET_TRANSACTION_ERROR,
        payload,
    }),
};

export const {
    getTransactionRequest,
    getTransactionStart,
    getTransactionStop,
    getTransactionRepeat,
    getTransactionSuccess,
    getTransactionError,
    setTransactionDownloadSource,
} = GetTransactionActions;

export type GetTransactionActionTypes = GetActionsType<typeof GetTransactionActions>;
