import _ from 'lodash';
import { emptyNObject, INObjects } from '../types';
import { TransactionActionTypes } from './actions';
import { Type } from './actionTypes';
import { Transaction, TransactionStatus } from '../../api/types';

export const initialState: TransactionState = emptyNObject;

/** Transaction reducer state type */
export type TransactionState = INObjects<Transaction>;

/**
 *  Transaction reducer
 * @param state
 * @param action
 */
export const reducer = (state = initialState, action: TransactionActionTypes): TransactionState => {
    switch (action.type) {
        case Type.CREATE_LOCAL_TRANSACTION_SUCCESS: {
            const { transaction } = action.payload;

            return {
                ...state,
                byId: {
                    ...state.byId,
                    [transaction.uuid]: transaction,
                },
                allIds: state.allIds.concat([transaction.uuid]),
            };
        }

        case Type.CREATE_TRANSACTION_START: {
            const { uuid, skillId } = action.payload;
            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        status: TransactionStatus.NEW,
                        skillId,
                    },
                },
            };
        }

        case Type.CREATE_TRANSACTION_SUCCESS: {
            const { uuid, transactionId } = action.payload;

            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        status: TransactionStatus.NEW,
                        transactionId,
                    },
                },
            };
        }

        case Type.CREATE_TRANSACTION_MOBILE_SUCCESS: {
            const { uuid, transactionId, mobileUrl } = action.payload;

            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        status: TransactionStatus.NEW,
                        transactionId,
                        mobileUrl
                    },
                },
            };
        }

        case Type.CREATE_TRANSACTION_ERROR: {
            const { uuid } = action.payload;
            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        status: TransactionStatus.FAILED,
                    },
                },
            };
        }

        case Type.GET_TRANSACTION_SUCCESS: {
            const {
                uuid,
                status,
                sourceFiles,
                reviewLink,
                resultFiles,
                resultClassNames,
            } = action.payload;

            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        status,
                        transactionFiles: sourceFiles ?? state.byId[uuid].transactionFiles,
                        reviewLink,
                        resultFiles,
                        resultClassNames,
                    },
                },
            };
        }

        case Type.ADD_FILE_TO_TRANSACTION_SUCCESS: {
            const {
                uuid,
                transactionFiles,
            } = action.payload;
            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        transactionFiles: state.byId[uuid].transactionFiles.concat(transactionFiles)
                    },
                },
            };
        }

        case Type.DELETE_FILE_FROM_TRANSACTION: {
            const {
                uuid,
                fileId,
            } = action.payload;
            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        transactionFiles: state.byId[uuid].transactionFiles.filter(file=>file.fileId != fileId)
                    },
                },
            };
        }

        case Type.DOWNLOAD_TRANSACTION_FILE_START: {
            return state
        }

        case Type.DOWNLOAD_TRANSACTION_FILE_SUCCESS: {
            const { uuid } = action.payload;
                return {
                    ...state,
                    byId: {
                        ...state.byId,
                        [uuid]: {
                            ...state.byId[uuid],
                        },
                    },
                };
        }

        case Type.DELETE_TRANSACTION_START: {
            const { uuid } = action.payload;

            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        deleting: true,
                    },
                },
            };
        }

        case Type.DELETE_TRANSACTION_SUCCESS: {
            const { uuid } = action.payload;

            return {
                ...state,
                byId: _.omit(state.byId, [uuid]),
                allIds: state.allIds.filter((id) => id !== uuid),
            };
        }

        case Type.DELETE_TRANSACTION_ERROR: {
            const { uuid } = action.payload;

            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        deleting: false,
                    },
                },
            };
        }

        case Type.SET_TRANSACTION_DOWNLOAD_SOURCE: {
            const { uuid, isDownload } = action.payload;

            return {
                ...state,
                byId: {
                    ...state.byId,
                    [uuid]: {
                        ...state.byId[uuid],
                        downloadingSource: isDownload,
                    },
                },
            };
        }
        default:
            return state;
    }
};
