import { put } from 'redux-saga/effects';
import mime from 'mime-types';
import { resource } from '../../../assets/text/resources';
import { SagaIterator } from 'redux-saga';
import { TransactionFileType} from "@api/types";
import {
    addFileToTransactionError,
    addFileToTransactionRequest,
    addFileToTransactionSuccess
} from "@ducks/Transaction/actions/addFileToTransactionActions";

export default function* addFileToTransactionSaga({
    payload,
}: ReturnType<typeof addFileToTransactionRequest>): SagaIterator {
        if (payload.transactionFiles.length>0) {
            let checkedTransactionFiles: TransactionFileType[] = [];
            let hasError = false;
            payload.transactionFiles.forEach(transactionFile =>{
                let isAvailableMimeFlag = true
                if(transactionFile.file.type) {
                    const isAvailableMime = ['pdf', 'jpg',  "pjpeg", "jpeg", "pjp", 'tiff', 'tif', 'gif', 'x-jbig2', 'jp2', 'bmp', 'png', "dib", "gif", 'html', 'htm',
                        'txt', 'rtf', 'odt', 'doc', 'docx',  "doc", "docx", "docm", "tiff", "tif", "jfif", "txt", "rle", "jp2", "j2k", "jpf", "jpx", "jpc", "jb2", "jbig2", true]
                        .includes(mime.extension(transactionFile.file.type))
                    isAvailableMimeFlag = isAvailableMime
                } else {
                    const fileExt = transactionFile.file.name.split('.').pop();
                    if(!fileExt || !["pdf", "doc", "docx", "docm", "tiff", "tif", "jfif", "pjpeg", "jpeg", "pjp", "jpg", "png", "bmp", "dib", "gif", "odt", "rtf", "html", "htm", "txt", "rle", "jp2", "j2k", "jpf", "jpx", "jpc", "jb2", "jbig2"]
                        .includes(fileExt)) {
                        isAvailableMimeFlag = false
                    }
                }
                if(isAvailableMimeFlag) {
                    checkedTransactionFiles = checkedTransactionFiles.concat(transactionFile)
                } else {
                    hasError = true
                }
            })

            yield put(addFileToTransactionSuccess({
                uuid: payload.uuid,
                transactionFiles: checkedTransactionFiles
            }));
            if(hasError) {
                yield put(addFileToTransactionError({ errorText: resource.error.unsupportedFileFormat }));
            }
        } else {
            yield put(addFileToTransactionError({ errorText: resource.error.otherError }));
        }
}
