import { runSaga } from 'redux-saga';
import { getTransactionRepeat, getTransactionStop, TransactionActionTypes } from '../actions';
import checkTransactionSaga from './checkTransactionSaga';
import { Type } from '../actionTypes';

describe('Check transaction tests', () => {
    jest.spyOn(console, 'error').mockImplementation();
    it('Check transaction - Processed', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        status: 'Processed',
                    },
                },
            },
            allIds: ['uuid-1', 'uuid-2'],
        };

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
                getState: () => fakeStore,
            },
            checkTransactionSaga,
            {
                type: Type.CREATE_TRANSACTION_SUCCESS,
                payload: {
                    uuid: 'uuid-1',
                    transactionId: 'transaction-id-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            getTransactionStop({
                transactionId: 'transaction-id-1',
            }),
        );
    });

    it('Check transaction - Failed', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        status: 'Failed',
                    },
                },
            },
            allIds: ['uuid-1', 'uuid-2'],
        };

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
                getState: () => fakeStore,
            },
            checkTransactionSaga,
            {
                type: Type.CREATE_TRANSACTION_SUCCESS,
                payload: {
                    uuid: 'uuid-1',
                    transactionId: 'transaction-id-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            getTransactionStop({
                transactionId: 'transaction-id-1',
            }),
        );
    });

    it('Check transaction - Processing', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        status: 'Processing',
                    },
                },
            },
            allIds: ['uuid-1', 'uuid-2'],
        };

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
                getState: () => fakeStore,
            },
            checkTransactionSaga,
            {
                type: Type.CREATE_TRANSACTION_SUCCESS,
                payload: {
                    uuid: 'uuid-1',
                    transactionId: 'transaction-id-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            getTransactionRepeat({
                uuid: 'uuid-1',
                transactionId: 'transaction-id-1',
            }),
        );
    });

    it('Check transaction - Review', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        status: 'Review',
                    },
                },
                allIds: ['uuid-1', 'uuid-2'],
            },
        };

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
                getState: () => fakeStore,
            },
            checkTransactionSaga,
            {
                type: Type.CREATE_TRANSACTION_SUCCESS,
                payload: {
                    uuid: 'uuid-1',
                    transactionId: 'transaction-id-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            getTransactionRepeat({
                uuid: 'uuid-1',
                transactionId: 'transaction-id-1',
            }),
        );
    });
});
