import { delay, put, select } from 'redux-saga/effects';
import {createTransactionSuccess, getTransactionRepeat, getTransactionRequest, getTransactionStop} from '../actions';
import { Transaction, TransactionStatus } from '../../../api/types';
import { transactionByIdSelector } from '../selectors/transactionByIdSelector';
import { SagaIterator } from 'redux-saga';

const POLLING_DELAY = 3000;

export default function* checkTransactionSaga({ payload }: ReturnType<typeof createTransactionSuccess>): SagaIterator {
    const transaction: Transaction = yield select(transactionByIdSelector, payload.uuid);
    try {
        if (transaction && transaction.transactionId) {
            if ([TransactionStatus.PROCESSED, TransactionStatus.FAILED].includes(transaction.status)) {
                yield put(
                    getTransactionStop({
                        transactionId: transaction.transactionId,
                    }),
                );
            } else {
                if (!transaction.downloadingSource) {
                    yield put(
                        getTransactionRequest({
                            uuid: payload.uuid,
                            transactionId: transaction.transactionId,
                            skillId: transaction.skillId || '',
                            needLoadSource: transaction.isMobile
                                && (!transaction.transactionFiles || transaction.transactionFiles.length == 0)
                                && transaction.status != TransactionStatus.NEW
                        }),
                    );
                }

                if (
                    [TransactionStatus.PROCESSING, TransactionStatus.REVIEW, TransactionStatus.NEW].includes(
                        transaction.status,
                    )
                ) {
                    yield delay(POLLING_DELAY);
                    yield put(
                        getTransactionRepeat({
                            uuid: payload.uuid,
                            transactionId: transaction.transactionId,
                        }),
                    );

                }

            }
        }
    } catch (error) {
        console.error(error);
    }
}
