import { put } from 'redux-saga/effects';
import mime from 'mime-types';
import { createLocalTransactionError, createLocalTransactionRequest, createLocalTransactionSuccess } from '../actions';
import { resource } from '../../../assets/text/resources';
import { SagaIterator } from 'redux-saga';
import {TransactionFileType} from "@api/types";

export default function* createLocalTransactionSaga({
    payload,
}: ReturnType<typeof createLocalTransactionRequest>): SagaIterator {
    if (!(payload.transaction.transactionFiles.length>0) && payload.transaction.isMobile) {
        yield put(createLocalTransactionSuccess(payload));
    } else {
        if (payload.transaction.transactionFiles.length>0) {
            let checkedTransactionFiles: TransactionFileType[] = [];
            let hasError = false;
            payload.transaction.transactionFiles.forEach(transactionFile =>{
                let isAvailableMimeFlag = true
                if(transactionFile.file.type) {
                    const isAvailableMime = ['pdf', 'jpg', 'pjpeg', 'jpeg', 'pjp', 'tiff', 'tif', 'gif', 'x-jbig2', 'jp2', 'bmp', 'png', "dib", 'gif', 'html', 'htm',
                        'txt', 'rtf', 'odt', 'doc', 'docx', "doc", "docx", "docm", "tiff", "tif", "jfif", "txt", "rle", "jp2", "j2k", "jpf", "jpx", "jpc", "jb2", "jbig2", true]
                        .includes(mime.extension(transactionFile.file.type))
                    isAvailableMimeFlag = isAvailableMime
                } else {
                    const fileExt = transactionFile.file.name.split('.').pop();
                    if(!fileExt || !["pdf", "doc", "docx", "docm", "tiff", "tif", "jfif", "pjpeg", "jpeg", "pjp", "jpg", "png", "bmp", "dib", "gif", "odt", "rtf", "html", "htm", "txt", "rle", "jp2", "j2k", "jpf", "jpx", "jpc", "jb2", "jbig2"]
                        .includes(fileExt)) {
                        isAvailableMimeFlag = false
                    }
                }
                if(isAvailableMimeFlag) {
                    checkedTransactionFiles = checkedTransactionFiles.concat(transactionFile)
                } else {
                    hasError = true
                }
            })
            payload.transaction.transactionFiles = checkedTransactionFiles;
            if(checkedTransactionFiles.length>0) {
                yield put(createLocalTransactionSuccess(payload));
            }
            if(hasError) {
                yield put(createLocalTransactionError({ errorText: resource.error.unsupportedFileFormat }));
            }
        } else {
            yield put(createLocalTransactionError({ errorText: resource.error.otherError }));
        }
    }
}
