import { ActionPattern, call, put, race, take } from 'redux-saga/effects';
import transactionService, {
    CreateTransactionRequestData,
    CreateTransactionResponse, GetMobileInputLinkResponse,
} from '../../../api/transactionService';
import {
    createTransactionError, createTransactionMobileRequest, createTransactionMobileSuccess,
    createTransactionStart,
    DeleteTransactionActionTypes,
} from '../actions';
import { resource } from '../../../assets/text/resources';
import { Type } from '../actionTypes';
import { SagaIterator } from 'redux-saga';
import {getMobileLinkSuccess, qrCodeShow} from '@ducks/Mobile/actions/MobileCaptureActions';
import { Action } from 'redux';

export default function* createMobileTransactionSaga({
    payload,
}: ReturnType<typeof createTransactionMobileRequest>): SagaIterator {
    try {
        yield put(
            createTransactionStart({
                uuid: payload.transaction.uuid,
                skillId: payload.skillId,
            }),
        );

        const data: CreateTransactionRequestData = {
            skillId: payload.skillId,
        };
        
        const takeArg: ActionPattern<Action<any>> = 
            (action: Action<any>) =>
            {
                const deleteAction = action as DeleteTransactionActionTypes;
                if (deleteAction.type === Type.DELETE_TRANSACTION_SUCCESS)
                {
                    return deleteAction.payload.uuid === payload.transaction.uuid;
                }
                else
                    return false;
            }

        const raceResult: { res: any; cancel: any } = yield race({
            res: call(transactionService.createTransaction, data),
            cancel: take(takeArg),
        });
        if (raceResult.cancel) {
            return;
        }
        const response: CreateTransactionResponse = raceResult.res;
        if (response.data.transactionId) {
            const mobileLinkResponse: GetMobileInputLinkResponse = yield call(transactionService.getMobileLink, response.data.transactionId);
            yield put(
                getMobileLinkSuccess(mobileLinkResponse.data),
            );
            yield put(
                createTransactionMobileSuccess({
                    uuid: payload.transaction.uuid,
                    mobileUrl: mobileLinkResponse.data.mobileInputLink,
                    transactionId: response.data.transactionId,
                }),
            );
            yield put(
                qrCodeShow({
                    transactionId: response.data.transactionId,
                }),
            );
        }
    } catch (error) {
        console.error(resource.error.createTransactionFailed);
        console.error(error);
        yield put(
            createTransactionError({
                uuid: payload.transaction.uuid,
                errorText: resource.error.createTransactionFailed,
            }),
        );
    }
}
