import { runSaga } from 'redux-saga';
import transactionService from '../../../api/transactionService';
import createTransactionSaga from './createTransactionSaga';
import MockFile from '../../../utils/mockFileUtil';
import {
    createTransactionError,
    createTransactionStart,
    createTransactionSuccess,
    TransactionActionTypes,
} from '../actions';
import { Type } from '../actionTypes';
import { resource } from '../../../assets/text/resources';
import {FileStatus, TransactionStatus} from '../../../api/types';

describe('Create Transaction Saga tests', () => {
    jest.spyOn(console, 'error').mockImplementation();
    it('Create transaction success', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const dummyTransaction = {
            data: {
                transactionId: 'transaction-id-1',
            },
            status: 200,
            statusText: 'OK',
            headers: {},
            config: {},
        };
        const data = MockFile({
            type: 'image/png',
            size: 50000,
        });
        const createTransaction = jest
            .spyOn(transactionService, 'createTransactionLaunch')
            .mockImplementation(() => Promise.resolve(dummyTransaction));

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            createTransactionSaga,
            {
                type: Type.CREATE_TRANSACTION_REQUEST,
                payload: {
                    transaction: {
                        uuid: 'uuid-1',
                        transactionFiles: [{
                            fileId: 'uuid-file-1',
                            file: data,
                            status: FileStatus.ADDED
                        }],
                        status: TransactionStatus.LOCAL,
                    },
                    skillId: 'Skill',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            createTransactionStart({
                uuid: 'uuid-1',
                skillId: 'Skill',
            }),
        );
        expect(dispatched).toContainEqual(
            createTransactionSuccess({
                uuid: 'uuid-1',
                transactionId: 'transaction-id-1',
            }),
        );
        expect(createTransaction).toHaveBeenCalled();
    });

    it('Create transaction failed', async () => {
        const dispatched = [] as Array<TransactionActionTypes>;
        const createTransaction = jest
            .spyOn(transactionService, 'createTransactionLaunch')
            .mockImplementation(() => Promise.reject());

        const testFile = MockFile({
            type: 'image/png',
            size: 50000,
        });

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            createTransactionSaga,
            {
                type: Type.CREATE_TRANSACTION_REQUEST,
                payload: {
                    transaction: {
                        uuid: 'uuid-1',
                        transactionFiles: [{
                            fileId: 'uuid-file-1',
                            file: testFile,
                            status: FileStatus.ADDED
                        }],
                        status: TransactionStatus.LOCAL,
                    },
                    skillId: 'Skill',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            createTransactionStart({
                uuid: 'uuid-1',
                skillId: 'Skill',
            }),
        );
        expect(dispatched).toContainEqual(
            createTransactionError({
                uuid: 'uuid-1',
                errorText: resource.error.createTransactionFailed,
            }),
        );
        expect(createTransaction).toHaveBeenCalled();
    });
});
