import {ActionPattern, call, put, race, take} from 'redux-saga/effects';
import transactionService, {
    CreateTransactionLaunchRequestData,
    CreateTransactionResponse,
} from '../../../api/transactionService';
import {
    createTransactionError,
    createTransactionRequest,
    createTransactionStart,
    createTransactionSuccess,
    DeleteTransactionActionTypes,
} from '../actions';
import {resource} from '../../../assets/text/resources';
import {Type} from '../actionTypes';
import {SagaIterator} from 'redux-saga';
import { Action } from 'redux';
import {getFileExpansion, getSelfName} from "@utils/getFileAttribute";

export default function* createTransactionSaga({payload}: ReturnType<typeof createTransactionRequest>): SagaIterator {
    try {
        if (!payload.transaction.transactionFiles) {
            throw new Error('File not exist in transaction');
        }
        yield put(
            createTransactionStart({
                uuid: payload.transaction.uuid,
                skillId: payload.skillId,
            }),
        );

        const formData = new FormData();
        let fileNames: string[] = [];
        payload.transaction.transactionFiles.forEach((transactionFile) => {
            fileNames.push(getSelfName(transactionFile.file.name));
            const fileIndex = fileNames.filter(name => name == getSelfName(transactionFile.file.name)).length;

            const fileName = fileIndex > 1 ? getSelfName(transactionFile.file.name) + "_" + (fileIndex-1) + getFileExpansion(transactionFile.file.name) : transactionFile.file.name;
            formData.append('Files', transactionFile.file, fileName);
        })
        const data: CreateTransactionLaunchRequestData = {
            skillId: payload.skillId,
            files: formData,
        };
        
        const takeArg: ActionPattern<Action<any>> = 
            (action: Action<any>) =>
            {
                const deleteAction = action as DeleteTransactionActionTypes;
                if (deleteAction.type === Type.DELETE_TRANSACTION_SUCCESS)
                {
                    return deleteAction.payload.uuid === payload.transaction.uuid;
                }
                else
                    return false;
            }

        const raceResult: { res: any; cancel: any } = yield race({
            res: call(transactionService.createTransactionLaunch, data),
            cancel: take(takeArg),
        });
        if (raceResult.cancel) {
            return;
        }
        const response: CreateTransactionResponse = raceResult.res;
        yield put(
            createTransactionSuccess({
                uuid: payload.transaction.uuid,
                transactionId: response.data.transactionId,
            }),
        );
    } catch (error) {
        console.error(resource.error.createTransactionFailed);
        console.error(error);
        yield put(
            createTransactionError({
                uuid: payload.transaction.uuid,
                errorText: resource.error.createTransactionFailed,
            }),
        );
    }
}
