import { call, put, select } from 'redux-saga/effects';
import transactionService from '../../../api/transactionService';
import {
    deleteTransactionError,
    deleteTransactionRequest,
    deleteTransactionStart,
    deleteTransactionSuccess,
    getTransactionStop,
} from '../actions';
import { resource } from '../../../assets/text/resources';
import { transactionByIdSelector } from '../selectors/transactionByIdSelector';
import { Transaction } from '../../../api/types';
import { SagaIterator } from 'redux-saga';

export default function* deleteTransactionSaga({ payload }: ReturnType<typeof deleteTransactionRequest>): SagaIterator {
    const transaction: Transaction = yield select(transactionByIdSelector, payload.uuid);
    try {
        yield put(
            deleteTransactionStart({
                uuid: payload.uuid,
            }),
        );
        if (transaction.transactionId) {
            yield call(transactionService.deleteTransaction, transaction.transactionId);

            yield put(getTransactionStop({ transactionId: transaction.transactionId }));
            yield put(deleteTransactionSuccess(payload));
        } else {
            yield put(deleteTransactionSuccess(payload));
        }
    } catch (error) {
        console.error(resource.error.deleteTransactionFailed);
        console.error(error);
        yield put(
            deleteTransactionError({
                uuid: payload.uuid,
                errorText: resource.error.deleteTransactionFailed,
            }),
        );
    }
}
