import { call, put, select } from 'redux-saga/effects';
import download from 'js-file-download';
import transactionService, { DownloadFileResponse } from '../../../api/transactionService';
import {
    downloadTransactionError,
    downloadTransactionRequest,
    downloadTransactionStart,
    downloadTransactionSuccess,
} from '../actions';
import { resource } from '../../../assets/text/resources';
import { transactionByIdSelector } from '../selectors/transactionByIdSelector';
import {  Transaction } from '../../../api/types';
import { SagaIterator } from 'redux-saga';

export default function* downloadTransactionSaga({
    payload,
}: ReturnType<typeof downloadTransactionRequest>): SagaIterator {
    const transaction: Transaction = yield select(transactionByIdSelector, payload.uuid);
    try {
        yield put(
            downloadTransactionStart({
                uuid: payload.uuid,
                fileId: payload.fileId,
            }),
        );

        let response: DownloadFileResponse;

        const file = transaction.resultFiles?.find(file=> file.fileId == payload.fileId)

        if (transaction.transactionId && file) {

            switch (file.type) {
                case "json": {
                    response = yield call(
                        transactionService.downloadFile,
                        transaction.transactionId,
                        file.fileId,
                    );
                    yield put(
                        downloadTransactionSuccess({
                            uuid: payload.uuid,
                            fileId: payload.fileId,
                        }),
                    );
                    yield call(() => {
                        download(JSON.stringify(response.data), file.fileName || 'result', 'application/json');
                    });
                    break;
                }
                case "pdf": {
                    response = yield call(
                        transactionService.downloadFileAsBuffer,
                        transaction.transactionId,
                        file.fileId,
                    );
                    yield put(
                        downloadTransactionSuccess({
                            uuid: payload.uuid,
                            fileId: payload.fileId,
                        }),
                    );
                    yield call(() => {
                        download(response.data, file.fileName || 'result', 'application/pdf');
                    });
                    break;
                }
                case "txt": {
                    response = yield call(
                        transactionService.downloadFileAsBuffer,
                        transaction.transactionId,
                        file.fileId,
                    );
                    yield put(
                        downloadTransactionSuccess({
                            uuid: payload.uuid,
                            fileId: payload.fileId,
                        }),
                    );
                    yield call(() => {
                        download(response.data, file.fileName || 'result', 'text/plain');
                    });
                    break;
                }
                default: {
                    response = yield call(
                        transactionService.downloadFileAsBuffer,
                        transaction.transactionId,
                        file.fileId,
                    );
                    yield put(
                        downloadTransactionSuccess({
                            uuid: payload.uuid,
                            fileId: payload.fileId,
                        }),
                    );
                    yield call(() => {
                        download(response.data, file.fileName || 'result');
                    });
                    break;
                }
            }
        } else {
            throw new Error("Transaction don't contain transaction or file id");
        }
    } catch (error) {
        console.error(resource.error.downloadResultFileFailed);
        console.error(error);
        yield put(
            downloadTransactionError({
                uuid: payload.uuid,
                errorText: resource.error.downloadResultFileFailed,
                fileId: payload.fileId,
            }),
        );
    }
}
