import { useEffect } from 'react';
import type React from 'react';

export function useOnClickOutside(ref: React.RefObject<HTMLElement>, handler: (event: MouseEvent | TouchEvent) => void) {
	useEffect(() => {
		const listener = (event: MouseEvent | TouchEvent) => {
			if (!ref.current || ref.current.contains(event.target as Node)) {
				return;
			}
			handler(event);
		};

		document.addEventListener('mousedown', listener);
		document.addEventListener('touchend', listener);

		return () => {
			document.removeEventListener('mousedown', listener);
			document.removeEventListener('touchend', listener);
		};
	}, [ref, handler]);
}
