import React from 'react';
import styles from './CardListComponent.module.scss';
import CardComponent from '../CardComponent/CardComponent';
import { TransactionState } from '@ducks/Transaction/reducer';
import { Skill, Transaction } from '@api/types';

interface CardListComponentProps {
    /** Transactions (normalized object) */
    transactions: TransactionState;
    /** Skills */
    skills: Array<Skill>;
    /** Handler for skill change */
    handleSkillChange: (transaction: Transaction, skillId: string | null) => void;
    /** Handler for delete transaction */
    handleDelete: (transaction: Transaction) => void;
    /** Handler for download file from transaction */
    handleDownload: (transaction: Transaction, fileType: string) => void;
    /** Handler for delete file from transaction */
    handleDeleteFile: (transaction: Transaction, fileType: string) => void;
    /** Event handler for open QR Code for transaction */
    handleOpen: (transactionId: string) => void;
}

/**
 *  Component to render transaction card list
 */
function CardListComponent({
    transactions,
    skills,
    handleSkillChange,
    handleDelete,
    handleDownload,
    handleDeleteFile,
    handleOpen
}: CardListComponentProps) {
    return (
        <div className={styles.container}>
            {transactions.allIds.map((transactionUUID) => {
                const transaction = transactions.byId[transactionUUID];
                return (
                    <CardComponent
                        key={transaction.uuid}
                        transaction={transaction}
                        skills={skills}
                        handleDownload={handleDownload}
                        handleChange={handleSkillChange}
                        handleDelete={handleDelete}
                        handleDeleteFile = {handleDeleteFile}
                        handleOpen={handleOpen}
                    />
                );
            })}
        </div>
    );
}

export default CardListComponent;
