import React, {useState} from 'react';
import EmptyDocIcon from '@assets/icons/ic_emptyDoc.svg';
import ArrowLeftIcon from '@assets/icons/ic_arrow_left.svg';
import ArrowRightIcon from '@assets/icons/ic_arrow_right.svg';
import styles from './ImagePreviewComponent.module.scss';
import {TransactionFileType} from '@api/types';

type PreviewComponentProps = {
    /** Transaction files array */
    transactionFiles: Array<TransactionFileType>;
};

/**
 *  Component to render preview image for document card
 */
function ImagePreviewComponent({transactionFiles}: PreviewComponentProps) {
    const [isError, setIsError] = useState<boolean>(false);
    const [current, setCurrent] = useState<number>(0);
    const [currentId, setCurrentId] = useState<string>(transactionFiles[0].fileId);

    const errorHandler = () => {
        setIsError(true);
    }

    const setCurrentImage = (newIndex: number) => {
        let fileIndex = 0;
        setCurrent((prevState: number) => {
            fileIndex = prevState + newIndex
            return fileIndex
        });
        setCurrentId(transactionFiles[fileIndex].fileId)
        setIsError(false)
    }
    if( !transactionFiles.find(transactionFile => transactionFile.fileId == currentId) ) {
        if(current>0) {
            setCurrentImage(-1);
        } else {
            setCurrentImage(1)
        }
    }
    if( current > transactionFiles.length-1) {
        setCurrentImage(-1)
    }
    let file
    if(transactionFiles[current]){
        file = React.useMemo(() => URL.createObjectURL(transactionFiles[current].file), [transactionFiles[current].file])
    }
    return (
        <div className={styles.previewContainer}>
            <div className={styles.pictureContainer}>
                {isError ?
                    <EmptyDocIcon className={styles.emptyPictureIcon}/> :
                    <img className={styles.picture} src={file} alt='' onError={errorHandler}/>
                }
            </div>
            {current > 0 ?
                <button className={styles.leftButton} onClick={() => setCurrentImage(-1)}>
                    <ArrowLeftIcon/>
                </button> : null}
            {current < transactionFiles.length-1 ?
                <button className={styles.rightButton} onClick={() => setCurrentImage(1)}>
                    <ArrowRightIcon/>
                </button> : null
            }
        </div>
    );
}

export default React.memo(ImagePreviewComponent);
