import React from 'react';
import NoImageIcon from '@assets/icons/ic_no_image.svg';
import EmptyDocIcon from '@assets/icons/ic_emptyDoc.svg';
import VerificationIcon from '@assets/icons/ic_verification.svg';
import styles from './PreviewComponent.module.scss';
import { Transaction, TransactionStatus } from '@api/types';
import ImagePreviewComponent from "@routes/CardViewPage/components/ImagePreviewComponent/ImagePreviewComponent";

type PreviewComponentProps = {
    /** Transaction object */
    transaction: Transaction;
};

/**
 *  Component to render preview image for document card
 */
function PreviewComponent({ transaction }: PreviewComponentProps) {

    if (transaction.reviewLink) {
        return <VerificationIcon className={styles.verifiIcon} />;
    }

    if (transaction.transactionFiles && transaction.transactionFiles.length>0) {
        return <ImagePreviewComponent transactionFiles={transaction.transactionFiles}/>
    }

    if([TransactionStatus.PROCESSING, TransactionStatus.PROCESSED].includes(transaction.status)) {
        return (
            <div className={styles.noPicture}>
                <EmptyDocIcon className={styles.emptyPictureIcon} />
            </div>
        );
    }

    return (
        <div className={styles.noPicture}>
            <NoImageIcon className={styles.noPictureIcon} />
        </div>
    );
}

export default React.memo(PreviewComponent);
