import React, { useCallback } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import {
    createTransactionMobileRequest,
    createTransactionRequest,
    deleteFileFromTransaction,
    deleteTransactionRequest,
    downloadTransactionRequest,
} from '@ducks/Transaction/actions';
import CardListComponent from '../components/CardListComponent/CardListComponent';
import { transactionsSelector } from '@ducks/Transaction/selectors/transactionsSelector';
import { Transaction } from '@api/types';
import { skillsSelector } from '@ducks/Skill/selectors/skillsSelector';
import {getMobileLinkRequest, qrCodeShow} from "@ducks/Mobile/actions/MobileCaptureActions";

/**
 *  Container component to render transaction card list
 */
function CardListContainer() {
    const dispatch = useDispatch();
    const transactions = useSelector(transactionsSelector);
    const skills = useSelector(skillsSelector);

    const handleSkillChange = useCallback(
        (transaction: Transaction, skillId: string | null) => {
            if (skillId) {
                if (transaction.isMobile) {
                    dispatch(createTransactionMobileRequest({ transaction, skillId }));
                } else {
                    dispatch(createTransactionRequest({ transaction, skillId }));
                }
            }
        },
        [dispatch],
    );

    const handleDelete = useCallback(
        (transaction: Transaction) => {
            dispatch(deleteTransactionRequest({ uuid: transaction.uuid }));
        },
        [dispatch],
    );

    const handleDeleteFile = useCallback(
        (transaction: Transaction, fileId: string) => {
            dispatch(deleteFileFromTransaction({ uuid: transaction.uuid , fileId}));
        },
        [dispatch],
    );

    const handleOpen = useCallback(
        (transactionId: string) => {
            dispatch(qrCodeShow({ transactionId: transactionId }));
            dispatch(getMobileLinkRequest({transactionId: transactionId}));
        },
        [dispatch],
    );

    const handleDownload = useCallback(
        (transaction: Transaction, fileId: string) => {
            dispatch(downloadTransactionRequest({ uuid: transaction.uuid, fileId }));
        },
        [dispatch],
    );

    return (
        <CardListComponent
            transactions={transactions}
            skills={skills}
            handleSkillChange={handleSkillChange}
            handleDownload={handleDownload}
            handleDeleteFile={handleDeleteFile}
            handleDelete={handleDelete}
            handleOpen={handleOpen}
        />
    );
}

export default CardListContainer;
