import React from 'react';
import styles from './LoginPageComponent.module.scss';
import Logo from '@assets/logo_large.svg';
import PoweredByLogo from '@assets/logo_powered_by_abbyy.svg';
import IconSpinner from '@assets/icons/ic_spinner_large.svg';

import { resource } from '@assets/text/resources';

interface LoginPageComponentProps {
    /** handler sign in event */
    onSignIn: () => void;
    /** loader visibility flag */
    isLoading: boolean;
}

/**
 *  Component to render a Login Page
 */
function LoginPageComponent({ isLoading, onSignIn }: LoginPageComponentProps) {
    return (
        <div className={styles.page}>
            <div className={styles.title}>
                <Logo className={styles.logo} />
                <span>{resource.title.loginTitle}</span>
            </div>
            <div className={styles.inputGroup}>
                {isLoading ? (
                    <IconSpinner className={styles.rotateIcon} />
                ) : (
                    <div>
                        <button type="button" className={styles.submit} onClick={onSignIn}>
                            {resource.button.signIn}
                        </button>
                    </div>
                )}
            </div>
            <PoweredByLogo className={styles.powered} />
        </div>
    );
}

export default LoginPageComponent;
