/**
 * Get file expansion from filename
 *  @param filename - Full file name
 */
export const getFileExpansion = (filename: string) => {
    let fileExpansion = filename.slice(((filename.lastIndexOf('.') - 1) >>> 0) + 2);
    if (fileExpansion) {
        fileExpansion = `.${fileExpansion}`;
    }
    return fileExpansion;
};

/**
 * Get file type from filename
 *  @param filename - Full file name
 */
export const getFileType = (filename: string) => {
    let fileExtension = filename.split(".").pop();
    let splitFileName = filename.split("_");

    if (fileExtension && fileExtension.toUpperCase().includes("JSON") &&
        splitFileName.length > 1 &&
        splitFileName[splitFileName.length - 1].length > 14
    ) {
        let splitFileType = splitFileName[splitFileName.length - 1].split(".");
        return splitFileType[0];
    } else {
        return ""
    }
};

/**
 * Get file self name from filename
 * @param filename - Full file name
 */
export const getSelfName = (filename: string) => {
    let fileSelfName = filename.substr(0, filename.lastIndexOf('.') ? filename.lastIndexOf('.') : filename.length);
    let fileExtension = filename.split(".").pop();
    let splitFileName = filename.split("_");

    if (fileExtension && fileExtension.toUpperCase().includes("JSON") &&
        splitFileName.length > 1 &&
        splitFileName[splitFileName.length - 1].length > 14
    ) {
        splitFileName.pop();
        return splitFileName.join("");
    }

    if (!fileSelfName) {
        fileSelfName = filename;
    }
    return fileSelfName;
};
